;; Generated package description from ntlm.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "ntlm" "2.1.0.0.20260101.27" "NTLM (NT LanManager) authentication support" '((emacs "27.1")) :commit "07c786f8618b2847f7951ed0de3ccb45377e2bf8" :url "https://elpa.gnu.org/nongnu/ntlm.html" :authors '(("Taro Kawagishi" . "tarok@transpulse.org")) :maintainer '("Thomas Fitzsimmons" . "fitzsim@fitzsim.org") :keywords '("ntlm" "sasl" "comm"))
